@@ -51,6 +51,13 @@
 // Add deprecation support for Comgr on Linux
 // This can be removed in favor of generic [[deprecated]] in C23, which should
 // also allow us to more easily include support on Windows
+
+#ifndef AMD_COMGR_DEPRECATED
+#ifdef AMD_COMGR_BUILD
+#define AMD_COMGR_DEPRECATED(msg) // empty
+#endif
+#endif
+
 #ifndef AMD_COMGR_DEPRECATED
 #if defined __GNUC__ && (__GNUC__ > 5 || defined __clang__)
 #define AMD_COMGR_DEPRECATED(msg) __attribute__((deprecated(msg)))
@@ -87,7 +94,7 @@
 #endif
 
 #define AMD_COMGR_INTERFACE_VERSION_MAJOR 2
-#define AMD_COMGR_INTERFACE_VERSION_MINOR 6
+#define AMD_COMGR_INTERFACE_VERSION_MINOR 8
 
 #ifdef __cplusplus
 extern "C" {
@@ -209,6 +216,18 @@ extern "C" {
  */
 #define AMD_COMGR_VERSION_2_6
 
+/**
+ * The function was introduced or changed in version 2.7 of the interface
+ * and has the symbol version string of ``"amd_comgr_2.7"``.
+ */
+#define AMD_COMGR_VERSION_2_7
+
+/**
+ * The function was introduced or changed in version 2.7 of the interface
+ * and has the symbol version string of ``"amd_comgr_2.7"``.
+ */
+#define AMD_COMGR_VERSION_2_8
+
 /** @} */
 
 /**
@@ -260,10 +279,14 @@ typedef enum amd_comgr_language_s {
    * HIP.
    */
   AMD_COMGR_LANGUAGE_HIP = 0x4,
+  /**
+   * LLVM IR, either textual (.ll) or bitcode (.bc) format.
+   */
+  AMD_COMGR_LANGUAGE_LLVM_IR = 0x5,
   /**
    * Marker for last valid language.
    */
-  AMD_COMGR_LANGUAGE_LAST = AMD_COMGR_LANGUAGE_HIP
+  AMD_COMGR_LANGUAGE_LAST = AMD_COMGR_LANGUAGE_LLVM_IR
 } amd_comgr_language_t;
 
 /**
@@ -356,17 +379,21 @@ typedef enum amd_comgr_data_kind_s {
    */
   AMD_COMGR_DATA_KIND_AR = 0x11,
   /**
-   * The data is a bundled bitcode.
+   * The data is a bitcode bundle.
    */
   AMD_COMGR_DATA_KIND_BC_BUNDLE = 0x12,
   /**
-   * The data is a bundled archive.
+   * The data is an archive bundle.
    */
   AMD_COMGR_DATA_KIND_AR_BUNDLE = 0x13,
+  /**
+   * The data is an object file bundle.
+   */
+  AMD_COMGR_DATA_KIND_OBJ_BUNDLE = 0x14,
   /**
    * Marker for last valid data kind.
    */
-  AMD_COMGR_DATA_KIND_LAST = AMD_COMGR_DATA_KIND_AR_BUNDLE
+  AMD_COMGR_DATA_KIND_LAST = AMD_COMGR_DATA_KIND_OBJ_BUNDLE
 } amd_comgr_data_kind_t;
 
 /**
@@ -1382,6 +1409,93 @@ amd_comgr_action_info_get_option_list_item(
   size_t *size,
   char *option) AMD_COMGR_VERSION_1_8;
 
+/**
+ * @brief Set the bundle entry IDs of an action info object.
+ *
+ * When an action info object is created it has no bundle entry IDs. Some
+ * actions require that the action info object has bundle entry IDs
+ * defined.
+ *
+ * @param[in] action_info A handle to the action info object to be
+ * updated.
+ *
+ * @param[in] bundle_entry_ids An array of strings containing one or more
+ * bundle entry ID strings. If NULL then the bundle entry ID strings are
+ * cleared. These IDs are described at
+ * https://clang.llvm.org/docs/ClangOffloadBundler.html#bundle-entry-id
+ *
+ * @retval ::AMD_COMGR_STATUS_SUCCESS The function has
+ * been executed successfully.
+ *
+ * @retval ::AMD_COMGR_STATUS_ERROR_INVALID_ARGUMENT @p
+ * action_info is an invalid action info object. @p contains an invalid
+ * bundle ID not supported by this version of the code object manager
+ * library.
+ *
+ * @retval ::AMD_COMGR_STATUS_ERROR_OUT_OF_RESOURCES
+ * Unable to update action info object as out of resources.
+ */
+amd_comgr_status_t AMD_COMGR_API
+amd_comgr_action_info_set_bundle_entry_ids(
+  amd_comgr_action_info_t action_info,
+  const char *bundle_entry_ids[],
+  size_t count) AMD_COMGR_VERSION_2_8;
+
+/**
+ * @brief Get number of bundle entry IDs
+ *
+ * @param[in] action_info The action info object to query.
+ *
+ * @param[out] count The number of bundle entry IDs availible. This value
+ * can be used as an upper bound to the Index provided to the corresponding
+ * amd_comgr_get_bundle_entry_id() call.
+ *
+ * @retval ::AMD_COMGR_STATUS_SUCCESS The function has
+ * been executed successfully.
+ *
+ * @retval ::AMD_COMGR_STATUS_ERROR_INVALID_ARGUMENT @p
+ * action_info is an invalid action info object. @p size is NULL.
+ *
+ * @retval ::AMD_COMGR_STATUS_ERROR_OUT_OF_RESOURCES
+ * Unable to update the data object as out of resources.
+ */
+amd_comgr_status_t AMD_COMGR_API
+amd_comgr_action_info_get_bundle_entry_id_count(
+  amd_comgr_action_info_t action_info,
+  size_t *count) AMD_COMGR_VERSION_2_8;
+
+/**
+ * @brief Fetch the Nth specific bundle entry ID or that ID's length.
+ *
+ * @param[in] action_info The action info object to query.
+ *
+ * @param[in] index The index of the bundle entry ID to be returned.
+ *
+ * @param[in, out] size For out, the size of @p bundle_entry_id. For in,
+ * if @bundle_entry_id is NULL, set to the size of the Nth ID string including
+ * the terminating null character.
+ *
+ * @param[out] bundle_entry_id If not NULL, then the first @p size characters of
+ * the Nth bundle entry ID string are copied into @p bundle_entry_id. If NULL,
+ * no bundle entry ID is copied, and only @p size is updated (useful in order
+ * to find the size of the buffer requried to copy the bundle_entry_id string).
+ *
+ * @retval ::AMD_COMGR_STATUS_SUCCESS The function has
+ * been executed successfully.
+ *
+ * @retval ::AMD_COMGR_STATUS_ERROR_INVALID_ARGUMENT @p
+ * action_info is an invalid action info object. @p size is NULL.
+ *
+ * @retval ::AMD_COMGR_STATUS_ERROR_OUT_OF_RESOURCES
+ * Unable to update the data object as out of resources.
+ */
+amd_comgr_status_t AMD_COMGR_API
+amd_comgr_action_info_get_bundle_entry_id(
+  amd_comgr_action_info_t action_info,
+  size_t index,
+  size_t *size,
+  char *bundle_entry_id) AMD_COMGR_VERSION_2_8;
+
 /**
  * @brief Set the working directory of an action info object.
  *
@@ -1578,8 +1692,9 @@ typedef enum amd_comgr_action_kind_s {
    * Return @p AMD_COMGR_STATUS_ERROR if the link or unbundling fails.
    *
    * Return @p AMD_COMGR_STATUS_ERROR_INVALID_ARGUMENT
-   * if isa name is not set in @p info and does not match the isa name
-   * of all bc data objects in @p input.
+   * if IsaName is not set in @p info and does not match the isa name
+   * of all bc data objects in @p input, or if the Name field is not set for
+   * any DataObject in the input set.
    */
   AMD_COMGR_ACTION_LINK_BC_TO_BC = 0x4,
   /**
@@ -1737,10 +1852,58 @@ typedef enum amd_comgr_action_kind_s {
    * if isa name or language is not set in @p info.
    */
   AMD_COMGR_ACTION_COMPILE_SOURCE_WITH_DEVICE_LIBS_TO_BC = 0xF,
+  /**
+   * Compile a single source data object in @p input in order. For each
+   * successful compilation add a relocatable data object to @p result.
+   * Resolve any include source names using the names of include data objects
+   * in @p input. Resolve any include relative path names using the
+   * working directory path in @p info. Produce relocatable for hip name in @p
+   * info. Compile the source for the language in @p info. Link against
+   * the device-specific and language-specific bitcode device libraries
+   * required for compilation. Currently only supports HIP language.
+   *
+   * Return @p AMD_COMGR_STATUS_ERROR if any compilation
+   * fails.
+   *
+   * Return @p AMD_COMGR_STATUS_ERROR_INVALID_ARGUMENT
+   * if isa name or language is not set in @p info.
+   */
+  AMD_COMGR_ACTION_COMPILE_SOURCE_TO_RELOCATABLE = 0x10,
+  /**
+   * Compile each source data object in @p input and create a single executabele
+   * in @p result. Resolve any include source names using the names of include
+   * data objects in @p input. Resolve any include relative path names using the
+   * working directory path in @p info. Produce executable for isa name in @p
+   * info. Compile the source for the language in @p info. Link against
+   * the device-specific and language-specific bitcode device libraries
+   * required for compilation.
+   *
+   * Return @p AMD_COMGR_STATUS_ERROR if any compilation
+   * fails.
+   *
+   * Return @p AMD_COMGR_STATUS_ERROR_INVALID_ARGUMENT
+   * if isa name or language is not set in @p info.
+   */
+  AMD_COMGR_ACTION_COMPILE_SOURCE_TO_EXECUTABLE = 0x11,
+
+   /**
+   * Unbundle each source data object in @p input. These objects can be
+   * bitcode bundles, or an archive containing bitcode bundles. For each
+   * successful unbundling, add a bc object or archive object to @p result,
+   * depending on the corresponding input.
+   *
+   * Return @p AMD_COMGR_STATUS_ERROR if any unbundling
+   * fails.
+   *
+   * Return @p AMD_COMGR_STATUS_ERROR_INVALID_ARGUMENT
+   * if isa name or language is not set in @p info.
+   */
+  AMD_COMGR_ACTION_UNBUNDLE = 0x12,
+
   /**
    * Marker for last valid action kind.
    */
-  AMD_COMGR_ACTION_LAST = AMD_COMGR_ACTION_COMPILE_SOURCE_WITH_DEVICE_LIBS_TO_BC
+  AMD_COMGR_ACTION_LAST = AMD_COMGR_ACTION_UNBUNDLE
 } amd_comgr_action_kind_t;
 
 /**
@@ -2519,6 +2682,57 @@ amd_comgr_lookup_code_object(
     amd_comgr_code_object_info_t *info_list,
     size_t info_list_size) AMD_COMGR_VERSION_2_3;
 
+/**
+ * @ brief Given a code object and an ELF virtual address, map the ELF virtual
+ * address to a code object offset. Also, determine if the ELF virtual address
+ * maps to an offset in a data region that is defined by the ELF file, but that
+ * does not occupy bytes in the ELF file. This is typically true of offsets that
+ * that refer to runtime or heap allocated memory. For ELF files with defined
+ * sections, these data regions are referred to as NOBITS or .bss sections.
+ *
+ * @param[in] data The data object to be inspected for the given ELF virtual
+ * address. This should be of kind AMD_COMGR_DATA_KIND_EXECUTABLE.
+ *
+ * @param[in] elf_virtual_address The address used to calculate the code object
+ * offset.
+ *
+ * @param[out] code_object_offset The code object offset returned to the caller
+ * based on the given ELF virtual address.
+ *
+ * @param[out] slice_size For nobits regions: the size in bytes, starting from
+ * the provided virtual address up to the end of the segment. In this case, the
+ * slice size represents the number of contiguous unreadable addresses following
+ * the provided address.
+
+ * For bits regions: the size in bytes, starting from the provided virtual
+ * address up to either the end of the segment, or the start of a NOBITS region.
+ * In this case, slice size represents the number of contiguous readable
+ * addresses following the provided address.
+ *
+ * @param[out] nobits Set to true if the code object offset points to a location
+ * in a data region that does not occupy bytes in the ELF file, as described
+ * above.
+ *
+ * @retval ::AMD_COMGR_STATUS_SUCCESS The function has been executed
+ * successfully.
+ *
+ * @retval ::AMD_COMGR_STATUS_ERROR The provided code object has an invalid
+ * header due to a mismatch in magic, class, data, version, abi, type, or
+ * machine.
+ *
+ * @retval ::AMD_COMGR_STATUS_ERROR_INVALID_ARGUMENT @p data is not of
+ * kind AMD_COMGR_DATA_KIND_EXECUTABLE or invalid, or that the provided @p
+ * elf_virtual_address is not within the ranges covered by the object's
+ * load-type program headers.
+ */
+amd_comgr_status_t AMD_COMGR_API
+amd_comgr_map_elf_virtual_address_to_code_object_offset(
+    amd_comgr_data_t data,
+    uint64_t elf_virtual_address,
+    uint64_t *code_object_offset,
+    uint64_t *slice_size,
+    bool *nobits) AMD_COMGR_VERSION_2_7;
+
 /** @} */
 
 #ifdef __cplusplus
